import logging
import os
import time
from configparser import ConfigParser
from pathlib import Path

from langchain_core.messages import BaseMessage, SystemMessage, HumanMessage, BaseMessageChunk, AIMessageChunk
from langchain_core.outputs import LLMResult


from llm_repeator_redis.llm_services import LLMResourcesManager
from redis.exceptions import TimeoutError

from llm_repeator_redis.tools.init_tools import InitConfigTools

# 模块级别的日志配置
logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

if not logger.handlers:
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    stream_handler = logging.StreamHandler()
    stream_handler.setFormatter(formatter)
    logger.addHandler(stream_handler)

class LLMWorker:
    """

    """
    def __init__(self,
                 llm_json_path: str = None,
                 config_path: str = None,
                 default_model: str = None):
        """
        初始化 llm worker
        :param llm_json_path: llm 资源文件路径
        :param config_path: 配置文件路径
        :param default_model: 默认使用的 llm 的ID，汪指定的话，则使用 config.ini 中配置 local_llm 下的 local_llm_id
        """
        # 设置默认路径
        home = Path.home()
        default_config_dir = home / ".llm_repeator_redis" / "config"
        default_config_dir.mkdir(parents=True, exist_ok=True)

        if config_path is None:
            config_path = default_config_dir / "config.ini"
        if llm_json_path is None:
            llm_json_path = default_config_dir / "llm_resources.json"

        # 确保路径是字符串
        config_path = str(config_path)
        llm_json_path = str(llm_json_path)

        # 创建 config.ini 模板（如果不存在）
        if not os.path.exists(config_path):
            InitConfigTools.create_config_file(config_path)
            logging.info(f"Programme create a config file, you must set it correctly. path: {config_path}")

        # 创建 llm_resources.json 模板（如果不存在）
        if not os.path.exists(llm_json_path):
            InitConfigTools.create_llm_resources_file(llm_json_path)
            logging.info(
                f"Programme create a llm_resources.json file, you can add other llm to it. path: {llm_json_path}")

        from llm_repeator_redis.redis_services import RedisManager
        configparser: ConfigParser = ConfigParser()
        configparser.read(config_path, encoding="utf-8")

        self.redis_manager = RedisManager(configparser=configparser)
        self.llm_manager = LLMResourcesManager(json_path=llm_json_path)
        self.stream_name: str = configparser['redis_server']['request_stream_name']
        self.answer_map_name: str = configparser['redis_server']['answer_map_name']
        self.chunk_stream_prefix: str = configparser['redis_server']['chunk_stream_prefix']
        self.reasoning_stream_prefix: str = configparser['redis_server']['reasoning_stream_prefix']
        self.request_internal = float(configparser['llm_worker']['request_internal'])

        if default_model is not None:
            self.default_model = default_model
        else:
            self.default_model = configparser['local_llm']['local_llm_id']

    def run(self, internal: float = 3):
        """

        :return:
        """
        while True:
            current_time = time.time()

            request: {} = None

            try:
                request = self.redis_manager.pop_request(self.stream_name)
            except TimeoutError as e:
                # 修正字符串格式化，并确保变量名正确
                logger.warning("Failed to get pending requests: %s, and sleep %.2f seconds", str(e), internal)
                time.sleep(internal)

            if request:
                seq = request['seq']
                text_messages = request['messages']

                if "model" not in request:
                    model = None
                else:
                    model = request['model']

                action_type = request['action_type']

                if not model:
                    model = self.default_model

                messages: [BaseMessage] = []

                for msg in text_messages:
                    if msg['type'] == "system":
                        messages.append(SystemMessage(msg['content']))
                    elif msg['type'] == "human":
                        messages.append(HumanMessage(msg['content']))
                    else:
                        raise ValueError(f"Unknown message type: {msg['type']}")

                # 当 action_type 是 generate 时
                if str.lower(action_type) == "generate":
                    logger.info(f"begin the llm model: {model} to generate answer, seq: {seq}")

                    answer: LLMResult = self.llm_manager.generate(llm_key=model, base_messages=messages)

                    # print(answer.generations[0][0])

                    answer_text: str = answer.generations[0][0].text

                    self.redis_manager.save_response(seq=seq, model=model, response=answer_text)

                    logger.info(f"end the llm model: {model} to generate answer, seq: {seq}")

                # 当 action_type 是 stream 时
                elif str.lower(action_type) == "stream":
                    logger.info(f"begin the llm model: {model} to stream answer, seq: {seq}")

                    answer_text: str = ""

                    # 判断是否是 reason 模型正在工作
                    is_reason_working: bool = False

                    for chunk in self.llm_manager.stream(llm_key=model, base_messages=messages):

                        chunk_text: str

                        if isinstance(chunk, str):
                            chunk_text = chunk
                            answer_text += chunk
                        elif isinstance(chunk, AIMessageChunk):

                            if chunk.additional_kwargs is not None and 'reasoning_content' in chunk.additional_kwargs.keys():

                                # 原因还未开始
                                if is_reason_working == False:

                                    is_reason_working = True
                                    print("<think>" + chunk.additional_kwargs['reasoning_content'], end="", flush=True)
                                else:
                                    print(chunk.additional_kwargs['reasoning_content'], end="", flush=True)

                                # 此处增加了思考过程，在获取的时候可以增加
                                self.redis_manager.stream_chunk(seq=seq,
                                                                chunk_text=chunk.additional_kwargs['reasoning_content'],
                                                                chunk_stream_prefix=self.reasoning_stream_prefix)

                                continue


                            if chunk.content is None or chunk.content == "":
                                continue

                            if chunk.content is not None:

                                if is_reason_working == True:
                                    print("</think>", flush=True)
                                    is_reason_working = False

                            chunk_text = chunk.content
                            answer_text += chunk_text

                        self.redis_manager.stream_chunk(seq=seq,
                                                        chunk_text=chunk_text,
                                                        chunk_stream_prefix=self.chunk_stream_prefix)

                        # time.sleep(0.3)

                    # 设置 对话的完成状态
                    self.redis_manager.finish_stream(seq=seq, chunk_stream_prefix=self.chunk_stream_prefix)

                    logger.info(f"end the llm model: {model} to stream answer, seq: {seq}")

                else:
                    raise ValueError(f"Unknown action type: {action_type}")

                # 在请求中，是否开启了归档 （让请求也可以确定是否归档）
                request_enable_arch: bool = request['enable_arch']

                logger.debug(f"the request enable_arch: {request_enable_arch}")

                if request_enable_arch:
                    # 进行对话归档到 redis 的操作
                    logger.info(f"begin to archive the request: {seq}")
                    self.redis_manager.save_to_arch_redis(seq=seq,
                                                          model=model,
                                                          request_json=request,
                                                          answer_text=answer_text,
                                                          llm_manager=self.llm_manager)

            else:
                logger.debug(f"no request, sleep {self.request_internal} seconds")
                time.sleep(self.request_internal)

            now = time.time()

            if now - current_time > 60*2:
                current_time = time.time()
                logger.info(f"the llm worker is running, but no request")

def init():
    LLMWorker()
    logging.info("The init() function has been called")


from langchain_core.messages import BaseMessage, SystemMessage, HumanMessage

from llm_client_redis import LLMClientRedis
from llm_client_redis.tools import OutputTools

if __name__ == '__main__':
    llm_repeator_redis = LLMClientRedis()

    model: str = "home_qwen3:32b"

    messages: list[BaseMessage] = [SystemMessage("你是一个好助手"), HumanMessage("你好")]

    result: str = ""

    for chunk in llm_repeator_redis.request_stream(messages=messages, model=model):
        print(chunk, end='')
        result += chunk

    result = OutputTools.remove_think(result).strip()

    print()
    print(result)

    print('done')


__all__ = ['LLMResourcesManager', 'OutputTools', 'LLMWorker']

from llm_repeator_redis.llm_services.llm_resources_manager import LLMResourcesManager
from llm_repeator_redis.llm_services.llm_response import OutputTools
from llm_repeator_redis.llm_services.llm_worker import LLMWorker


from langchain_core.messages import BaseMessage, SystemMessage, HumanMessage

from llm_client_redis import LLMClientRedis

if __name__ == '__main__':
    llm_repeator_redis = LLMClientRedis()

    model: str = "huawei_deepseek_v3_32k"

    messages: list[BaseMessage] = [SystemMessage("你是一个好助手"), HumanMessage("你好")]

    answer = llm_repeator_redis.request(messages=messages, model=model)

    print(answer)

    print('done')


import ollama

def list_ollama_models():
    """
    List all available models

    :return: list of models
    """

    return [m.model for m in ollama.list()["models"]]



print(list_ollama_models())



import json
import logging


class InitConfigTools:
    @staticmethod
    def create_llm_resources_file(path: str):
        """

        :param path:
        :return:
        """
        template: dict = {
          "deepseek_r1": {
            "model": "deepseek-reasoner",
            "version": "R1",
            "base_url": "https://api.deepseek.com",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "DEEPSEEK_API_KEY",
            "response_type": "deepseek-reasoner",
            "description": "DeepSeek R1 模型 LangChain 接口"
          },
          "deepseek_v3": {
            "model": "deepseek-chat",
            "version": "V3",
            "base_url": "https://api.deepseek.com",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "DEEPSEEK_API_KEY",
            "response_type": "deepseek-chat",
            "description": "DeepSeek V3 模型 LangChain 接口"
          },
          "huawei_deepseek_r1_32k": {
            "model": "DeepSeek-R1",
            "version": "R1",
            "base_url": "https://maas-cn-southwest-2.modelarts-maas.com/deepseek-r1/v1",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "HUAWEI_MODEL_ART_API_KEY",
            "response_type": "deepseek-reasoner",
            "description": "华为云的 DeepSeek R1 32K 模型 LangChain DeepSeek 接口"
          },
          "huawei_deepseek_v3_32k": {
            "model": "DeepSeek-V3",
            "version": "V1",
            "base_url": "https://maas-cn-southwest-2.modelarts-maas.com/deepseek-v3/v1",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "HUAWEI_MODEL_ART_API_KEY",
            "response_type": "deepseek-chat",
            "description": "华为云的 DeepSeek V3 32K 模型 LangChain DeepSeek 接口"
          },
          "huawei_DeepSeek-R1-32K-0528": {
            "model": "deepseek-r1-250528",
            "version": "R1",
            "base_url": "https://api.modelarts-maas.com/v1",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "HUAWEI_MODEL_ART_API_KEY",
            "response_type": "deepseek-reasoner",
            "description": "华为云的 DeepSeek-R1-32K-0528 模型 LangChain DeepSeek 接口"
          },
          "huawei_qwen3-32b": {
            "model": "qwen3-32b",
            "version": "V1",
            "base_url": "https://api.modelarts-maas.com/v1",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "HUAWEI_MODEL_ART_API_KEY",
            "response_type": "deepseek-chat",
            "description": "华为云的 qwen3-32b 模型 LangChain DeepSeek 接口"
          },
          "huawei_qwen3-235b-a22b": {
            "model": "qwen3-235b-a22b",
            "version": "V1",
            "base_url": "https://api.modelarts-maas.com/v1",
            "type": "BaseChatOpenAI",
            "provider": "langchain-deepseek",
            "env_api_key_name": "HUAWEI_MODEL_ART_API_KEY",
            "response_type": "deepseek-chat",
            "description": "华为云的 qwen3-235b-a22b 模型 LangChain DeepSeek 接口"
          },
          "home_deepseek-r1:32b": {
            "model": "deepseek-r1:32b",
            "version": "32b",
            "base_url": "https://localhost:11434",
            "type": "BaseLLM",
            "provider": "langchain-ollama",
            "env_api_key_name": None,
            "response_type": "deepseek-reasoner",
            "description": "本地 DeepSeek R1 32b 模型 LangChain 接口"
          },
          "home_qwen3:32b": {
            "model": "qwen3:32b",
            "version": "32b",
            "base_url": "https://localhost:11434",
            "type": "BaseLLM",
            "provider": "langchain-ollama",
            "env_api_key_name": None,
            "response_type": "deepseek-reasoner",
            "description": "本地 qwen3:32b 模型 LangChain 接口"
          }
        }

        with open(path, "w", encoding="utf-8") as f:
            json.dump(template, f, indent=4)
        logging.info(f"Created default llm_resources.json at {path}")

    @staticmethod
    def create_config_file(path: str):
        """
        """
        template: str = """# config.ini

[redis_server]
# Redis 服务器的主机地址
host = localhost

# Redis 服务器的端口号
port = 6379

# Redis 密码的环境变量名称（通过环境变量读取密码）
password_env_var_name = REDIS_AUTHENTICATION

# Redis 数据库编号
db = 1

# 用于请求的 Redis 数据流名称
request_stream_name = request_stream

# 用于响应的 Redis 数据配对名称
answer_map_name = answer_map

# 用于响应的 Redis 数据流名称前辍，前辍包含:号，加上序号则表示响应流 list 的名称
chunk_stream_prefix = chunk_stream:

# 用于深入分析的 Redis 数据流名称前辍，前辍包含:号，加上序号则表示响应流 list 的名称
reasoning_stream_prefix = reasoning_stream:

[logging]
# 日志级别，可选值有 DEBUG, INFO, WARNING, ERROR, CRITICAL
level = INFO


[redis_arch]
# 是否启用 Redis 归档功能，true 表示启用，false 表示禁用
redis_arch_enable = true

# Redis 归档服务器的主机地址
redis_arch_host = localhost

# Redis 归档服务器的端口号
redis_arch_port = 6379

# Redis 归档服务器密码的环境变量名称（通过环境变量读取密码）
redis_arch_password_env_var_name = REDIS_AUTHENTICATION

# Redis 归档服务器使用的数据库编号
redis_arch_db = 2

# Redis 归档数据流名称
redis_arch_data_stream_name = arch_stream

# 开启本地llm 描述请求，并保存到归档内容，此时将使用 [local_llm] local_llm_id 来进行请求的描述，同时 describe_request_llm_id 不生效。
# 但如果 local_llm_id 为 false，同时 describe_request_llm_id 指定了有效的llm编号，则 使用指定llm来进行请求的描述。
enable_local_llm_describe_request = false

# 描述请求的llm编号，如果为空，则不描述请求，只有在 enable_local_llm_describe_request 为 false 时生效。
# 请注意，如果 enable_local_llm_describe_request 为 false 且 describe_request_llm_id 为空，则不会描述请求。
describe_request_llm_id=


[llm_worker]
# 获取请求的时间间隔
request_internal=0.3


[local_llm]
local_llm_id = home_qwen3:32b


[archive]
# 归档的文件路径
archive_dir_path = d:/llm_logs_archive/
# 归档的时间间隔（单位：秒）
archive_interval = 60
"""
        with open(path, "w", encoding="utf-8") as _f:
            _f.write(template)
        logging.info(f"Created default config.ini at {path}")


import json
import logging
import os
import time
from pathlib import Path

from langchain_core.messages import BaseMessage,  BaseMessageChunk
from langchain_core.outputs import LLMResult
from langchain_deepseek import ChatDeepSeek
from langchain_ollama import OllamaLLM
from openai import APITimeoutError
from typing_extensions import Iterator

# 模块级别的日志配置
logger = logging.getLogger(__name__)
logger.setLevel(logging.INFO)

if not logger.handlers:
    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    stream_handler = logging.StreamHandler()
    stream_handler.setFormatter(formatter)
    logger.addHandler(stream_handler)


class LLMResourcesManager:

    __providers = {
        "langchain-deepseek": ChatDeepSeek,
        "langchain-ollama": OllamaLLM
    }

    def __init__(self, json_path: str = None):

        if json_path is None:
            home_path: Path = Path.home()
            json_path = str(home_path / ".llm_repeator" / "config" / "llm_resources.json")

        with open(json_path, 'r', encoding='utf-8') as f:
            self.llm_dic: dict = json.load(f)

        logger.info(f'Loaded {len(self.llm_dic)} LLM resources from {json_path}')
        logger.info(logger.info(f'Available LLM resources: {self.llm_dic.keys()}'))

    @staticmethod
    def format_messages_to_text(base_messages: list[BaseMessage]) -> str:
        """
        自定义消息转文本函数（按模型需求调整格式）
        :return:
        """
        return "\n".join([f"'{msg.type}': '{msg.content}'" for msg in base_messages]).strip()

    def stream(self,
               llm_key: str,
               base_messages: list[BaseMessage],
               retry: int = 6,
               retry_internal: int = 20) -> Iterator[BaseMessageChunk] | None:
        """
        向 LLM 资源发出信息请求，将生成结果的 redis list 的名称进行反馈
        :param llm_key: LLM 资源 key
        :param base_messages: 消息列表
        :param retry: 重试次数, 默认 6 次
        :param retry_internal: 重试间隔, 默认 20 秒
        :return: redis list 的名称
        """
        if llm_key not in self.llm_dic:
            raise ValueError(f'LLM key {llm_key} not found in llm_resources.json')

        llm_def = self.llm_dic[llm_key]

        api_key = None

        if llm_def["env_api_key_name"]:
            api_key = os.getenv(llm_def["env_api_key_name"])

        if llm_def["type"] == "BaseChatOpenAI":
            llm: ChatDeepSeek
        elif llm_def["type"] == "BaseLLM":
            llm: OllamaLLM

        if api_key is None:
            llm = self.__providers[llm_def["provider"]](api_base=llm_def["base_url"], model=llm_def["model"])
        else:
            llm = self.__providers[llm_def["provider"]](api_base=llm_def["base_url"], model=llm_def["model"], api_key=api_key)

        retry_count: int = 0

        while retry_count < retry:
            try:
                if llm_def["type"] == "BaseChatOpenAI":
                    return llm.stream(base_messages)
                elif llm_def["type"] == "BaseLLM":
                    # 原实现很多时候反回英语
                    # return llm.generate([self.format_messages_to_text(base_messages=base_messages)])

                    text: str = ""

                    for msg in base_messages:
                        text += msg.content
                        text += "\n\n"

                    return llm.stream([text])
            except APITimeoutError as e:
                logger.error(f"API timeout error: {e}")
                logger.warning(f"Retry {retry_count} times, waiting {retry_internal} seconds")
                retry_count += 1
                time.sleep(retry_internal)
            except Exception as e:
                logger.error(f"Error: {e}")
                logger.warning(f"Retry {retry_count} times, waiting {retry_internal} seconds")
                retry_count += 1
                time.sleep(retry_internal)
            finally:
                if retry_count == retry:
                    logger.error(f"Retry {retry_count} times, still failed")
                    return None


    def generate(self, llm_key: str,
                 base_messages:list[BaseMessage],
                 retry: int = 6,
                 retry_internal: int = 20) -> LLMResult | None:

        """
        向 LLM 资源发出信息请求，将生成结果反馈
        :param llm_key: LLM 资源 key
        :param base_messages: 消息列表
        :param retry: 重试次数, 默认 6 次
        :param retry_internal: 重试间隔, 默认 20 秒
        :return: BaseMessage
        """
        if llm_key not in self.llm_dic:
            raise ValueError(f'LLM key {llm_key} not found in llm_resources.json')

        llm_def = self.llm_dic[llm_key]

        api_key = None

        if llm_def["env_api_key_name"]:
            api_key = os.getenv(llm_def["env_api_key_name"])

        if llm_def["type"] == "BaseChatOpenAI":
            llm: ChatDeepSeek
        elif llm_def["type"] == "BaseLLM":
            llm: OllamaLLM

        if api_key is None:
            llm = self.__providers[llm_def["provider"]](api_base=llm_def["base_url"], model=llm_def["model"])
        else:
            llm = self.__providers[llm_def["provider"]](api_base=llm_def["base_url"], model=llm_def["model"], api_key=api_key)

        retry_count: int = 0

        while retry_count < retry:
            try:
                if llm_def["type"] == "BaseChatOpenAI":
                    return llm.generate([base_messages])
                elif llm_def["type"] == "BaseLLM":
                    # 原实现很多时候反回英语
                    # return llm.generate([self.format_messages_to_text(base_messages=base_messages)])

                    text: str = ""

                    for msg in base_messages:
                        text += msg.content
                        text += "\n\n"

                    return llm.generate([text])
            except APITimeoutError as e:
                logger.error(f"API timeout error: {e}")
                logger.warning(f"Retry {retry_count} times, waiting {retry_internal} seconds")
                retry_count += 1
                time.sleep(retry_internal)
            except Exception as e:
                logger.error(f"Error: {e}")
                logger.warning(f"Retry {retry_count} times, waiting {retry_internal} seconds")
                retry_count += 1
                time.sleep(retry_internal)
            finally:
                if retry_count == retry:
                    logger.error(f"Retry {retry_count} times, still failed")
                    return None

    def list_llm_def(self):
        """
        列出所有 LLM 资源
        :return: LLM 资源 key 列表
        """
        return [key for key in self.llm_dic.keys()]

    def is_model_available(self, llm_key: str) -> bool:
        """
        判断是否存在指定 LLM 资源
        :param llm_key: LLM 资源 key
        :return: True or False
        """
        return llm_key in self.llm_dic



import json
import logging
import os.path
import time
from configparser import ConfigParser
from idlelib.pathbrowser import PathBrowser
from pathlib import Path

from llm_repeator_redis.redis_services import RedisManager

class ArchFromRedisWorker:
    def __init__(self, config_path: str = None):
        """

        :param config_path:
        """
        if config_path is None:
            home_path: Path = Path.home()
            config_path = os.path.join(home_path, '.llm_repeator_redis', 'config', 'config.ini')
        logging.info(f'ArchFromRedisWorker init start')

        configparser: ConfigParser = ConfigParser()
        configparser.read(config_path, encoding="utf-8")

        self.redis_manager = RedisManager(configparser=configparser)
        self.archive_interval: int = configparser.getint('archive', 'archive_interval')
        logging.info(f'archive_interval: {self.archive_interval}')

        self.archive_dir_path: str = configparser.get('archive', 'archive_dir_path')
        logging.info(f'archive_dir_path: {self.archive_dir_path}')
        logging.info(f'ArchFromRedisWorker init success')

    def run(self):
        while True:

            if not os.path.exists(self.archive_dir_path):
                logging.error(f'Archive directory {self.archive_dir_path} does not exist, sleeping for {self.archive_interval} seconds')
                time.sleep(self.archive_interval)
                continue

            logs: list = self.redis_manager.read_latest_from_arch_redis(count=2)

            if logs is None or len(logs) == 0:
                logging.debug(f'No logs to archive, sleeping for {self.archive_interval} seconds')
                time.sleep(self.archive_interval)
                continue

            for log in logs:

                model: str = log['request']['model']

                model = (model.replace('/', '_').replace('\\', '_')
                         .replace(':', '_').replace('*', '_').replace('?', '_')
                         .replace('"', '_').replace('<', '_').replace('>', '_')
                         .replace('|', '_'))

                model_dir = os.path.join(self.archive_dir_path, model)

                if not os.path.exists(model_dir):
                    os.makedirs(model_dir)
                    logging.info(f'Created directory {model_dir}')

                # 获取当天日期
                today: str = time.strftime("%Y-%m-%d", time.localtime())

                date_dir = os.path.join(model_dir, today)

                if not os.path.exists(date_dir):
                    os.makedirs(date_dir)
                    logging.info(f'Created directory {date_dir}')

                # 生成文件名
                # 获取当前时间的毫秒数
                current_time = time.strftime("%Y%m%d%H%M%S", time.localtime())

                file_name = f"{current_time}_{model}_{log['seq']}.json"

                file_path = os.path.join(date_dir, file_name)

                with open(file_path, 'w', encoding='utf-8') as f:
                    f.write(json.dumps(log, ensure_ascii=False, indent=4))
                    logging.info(f'Archived log to {file_path}')

            time.sleep(self.archive_interval)


if __name__ == '__main__':
    arch_worker = ArchFromRedisWorker()
    arch_worker.run()



from langchain_core.messages import BaseMessage, SystemMessage, HumanMessage

from llm_client_redis import LLMClientRedis

if __name__ == '__main__':
    llm_repeator_redis = LLMClientRedis()

    # model: str = "huawei_deepseek_r1_32k"
    model: str = "huawei_deepseek_v3_32k"

    messages: list[BaseMessage] = [SystemMessage("你是一个好助手"), HumanMessage("你好")]

    for chunk in llm_repeator_redis.request_stream(messages=messages, model=model):
        print(chunk, end='')

    print('done')
